@@ -2,7 +2,7 @@
   mxBeeBase -- BeeBase C extension
 
   Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -23,11 +23,18 @@
 /* Mark the module as Py_ssize_t clean. */
 #define PY_SSIZE_T_CLEAN 1
 
+/* Setup mxstdlib memory management */
+#if 1
+# define MAL_USE_PYMALLOC
+#else
+# define MAL_USE_C_MALLOC
+#endif
+
 #include "mx.h"
 #include "mxBeeBase.h"
 
 /* Version number: Major.Minor.Patchlevel */
-#define MXBEEBASE_VERSION "3.1.2"
+#define MXBEEBASE_VERSION "3.2.0"
 
 /* Define these to have the module use free lists (saves malloc calls) */
 /*#define MXBEEINDEX_FREELIST*/
@@ -40,7 +47,7 @@ static char *Module_docstring =
  MXBEEBASE_MODULE" -- BeeBase objects and functions. Version "MXBEEBASE_VERSION"\n\n"
 
  "Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -346,7 +353,8 @@ void *mxBeeIndex_KeyFromString(mxBeeIndexObject *beeindex,
 	      "keys must be strings");
     Py_AssertWithArg((int)PyString_GET_SIZE(key) < beeindex->info.keySize,
 		     PyExc_TypeError,
-		     "keys must not exceed length %i",beeindex->info.keySize - 1);
+		     "keys must not exceed length %li",
+		     (unsigned long)beeindex->info.keySize - 1);
     Py_Assert((unsigned int) PyString_GET_SIZE(key) == strlen(PyString_AS_STRING(key)),
 	      PyExc_TypeError,
 	      "keys may not have embedded null bytes");
@@ -383,7 +391,8 @@ void *mxBeeIndex_KeyFromFixedLengthString(mxBeeIndexObject *beeindex,
 	      "keys must be strings");
     Py_AssertWithArg((int)PyString_GET_SIZE(key) == beeindex->info.keySize - 1,
 		     PyExc_TypeError,
-		     "keys must have fixed length %i",beeindex->info.keySize - 1);
+		     "keys must have fixed length %li",
+		     (unsigned long)beeindex->info.keySize - 1);
 
     return (void*)PyString_AS_STRING(key);
     
