@@ -1,7 +1,7 @@
 """ Python part of the low-level DateTime[Delta] type implementation.
 
     Copyright (c) 1998-2001, Marc-Andre Lemburg; mailto:mal@lemburg.com
-    Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+    Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
     See the documentation for further information on copyrights,
     or contact the author. All Rights Reserved.
 """
@@ -15,7 +15,7 @@ oneMinute = DateTimeDelta(0,0,1)
 oneHour = DateTimeDelta(0,1)
 oneDay = DateTimeDelta(1)
 oneWeek = DateTimeDelta(7)
-Epoch = DateTimeFromAbsDateTime(1,0)
+Epoch = DateTimeFromAbsDateTime(1, 0)
 
 # Shortcuts for pickle; for backward compatibility only (they are now
 # defined in __init__.py to further reduce the pickles length)
@@ -27,12 +27,24 @@ def _DTD(seconds):
 # Module init
 class modinit:
 
-    global _time,_string,_math,_types
-    import time,string,math,types
+    global _time, _math, _types, _sys, _pydatetime, _pydate, _pytime, _pytimedelta
+    import time, math, types, sys
     _time = time
-    _string = string
     _math = math
     _types = types
+    _sys = sys
+    try:
+        import datetime
+        _pydatetime = datetime.datetime
+        _pydate = datetime.date
+        _pytime = datetime.time
+        _pytimedelta = datetime.timedelta
+    except ImportError:
+        # Set them to (), so that isinstance() works with them
+        _pydatetime = ()
+        _pydate = ()
+        _pytime = ()
+        _pytimedelta = ()
 
 del modinit
 
@@ -82,7 +94,9 @@ def localtime(ticks=None,
 def gmtime(ticks=None,
            # Locals:
            time=_time.time,float=float,gmtime=_time.gmtime,
-           round=round,int=int,DateTime=DateTime,floor=_math.floor):
+           round=round,int=int,DateTime=DateTime,floor=_math.floor,
+           DateTimeDeltaFromSeconds=DateTimeDeltaFromSeconds,
+           Unix_Epoch=DateTime(1970, 1, 1)):
 
     """gmtime(ticks=None)
 
@@ -97,6 +111,11 @@ def gmtime(ticks=None,
     else:
         ticks = float(ticks)
     ticks = round(ticks, 6)
+    if POSIX:
+        # On POSIX platforms, the calulation is easy (and this also
+        # makes the calulation safe against year 2038 wrap-arounds and
+        # errors); see #421
+        return Unix_Epoch + DateTimeDeltaFromSeconds(float(ticks))
     fticks = floor(ticks)
     Y,M,D,h,m,s = gmtime(ticks)[:6]
     s = s + (ticks - fticks)
@@ -227,8 +246,6 @@ def DateTimeFrom(*args, **kws):
         Generic DateTime instance constructor. Can handle parsing
         strings, numbers and keywords.
 
-        XXX Add support for Unicode.
-
     """
     if len(args) == 1:
         # Single argument
@@ -236,11 +253,23 @@ def DateTimeFrom(*args, **kws):
         argtype = type(arg)
         if _isstring(arg):
             import Parser
-            return apply(Parser.DateTimeFromString, args, kws)
+            return Parser.DateTimeFromString(*args, **kws)
         elif argtype is DateTimeType:
             return arg
         elif argtype is DateTimeDeltaType:
             raise TypeError,'cannot convert DateTimeDelta to DateTime'
+        elif isinstance(arg, _pydatetime):
+            if arg.tzinfo is not None:
+                # Convert to UTC
+                offset = arg.utcoffset()
+                arg -= offset
+            return DateTime(
+                arg.year, arg.month, arg.day,
+                arg.hour, arg.minute,
+                arg.second + arg.microsecond * 1e-6)
+        elif isinstance(arg, _pydate):
+            # Note: _pydatetime are subclasses of _pydates !
+            return DateTime(arg.year, arg.month, arg.day)
         else:
             try:
                 value = float(arg)
@@ -254,26 +283,81 @@ def DateTimeFrom(*args, **kws):
         if len(args) == 2 and _isstring(args[0]) and _isstring(args[1]):
             # interpret as date and time string
             import Parser
-            return apply(Parser.DateTimeFromString,
-                         (args[0] + ' ' + args[1],),
-                         kws)
+            return Parser.DateTimeFromString(
+                args[0] + ' ' + args[1],
+                **kws)
 
         # Assume the arguments are the same as for DateTime()
-        return apply(DateTime, args, kws)
+        if 'defaultdate' in kws:
+            raise TypeError('defaultdate is only supported when parsing '
+                            'strings or using keyword arguments only')
+        return DateTime(*args, **kws)
+
+    elif len(kws) > 0:
+        # Keyword arguments only; add defaults... today at 0:00:00
+        defaultdate = kws.get('defaultdate', None)
+        if defaultdate is None:
+            defaultdate = today()
+        hour = kws.get('hour', defaultdate.hour)
+        minute = kws.get('minute', defaultdate.minute)
+        second = kws.get('second', defaultdate.second)
+        day = kws.get('day', defaultdate.day)
+        month = kws.get('month', defaultdate.month)
+        year = kws.get('year', defaultdate.year)
+        return DateTime(year,month,day,hour,minute,second)
+
+    else:
+        raise TypeError(
+            'cannot convert date/time arguments to DateTime: '
+            'args=%r, kws=%r' % (args, kws))
+
+def DateFrom(*args, **kws):
+
+    """ DateFrom(*args, **kws)
+
+        Generic DateTime instance constructor. Can handle parsing
+        strings, numbers and keywords, but only works on the date
+        part.
+
+    """
+    if len(args) == 1:
+        # Single argument
+        arg = args[0]
+        argtype = type(arg)
+        if _isstring(arg):
+            import Parser
+            return Parser.DateFromString(*args, **kws)
+        elif argtype is DateTimeType:
+            return arg
+        elif argtype is DateTimeDeltaType:
+            raise TypeError,'cannot convert DateTimeDelta to DateTime'
+        elif isinstance(arg, _pydate):
+            # Note: _pydatetime are subclasses of _pydates !
+            return DateTime(arg.year, arg.month, arg.day)
+        else:
+            try:
+                value = float(arg)
+            except (TypeError, ValueError):
+                value = int(arg)
+            assert not kws
+            return DateTimeFromTicks(value)
+
+    elif len(args) > 1:
+        # Assume the arguments are the same as for DateTime()
+        return DateTime(*args, **kws)
 
     elif len(kws) > 0:
         # Keyword arguments; add defaults... today at 0:00:00
-        hour = kws.get('hour',0)
-        minute = kws.get('minute',0)
-        second = kws.get('second',0)
         today = now()
         day = kws.get('day',today.day)
         month = kws.get('month',today.month)
         year = kws.get('year',today.year)
-        return DateTime(year,month,day,hour,minute,second)
+        return DateTime(year,month,day)
 
     else:
-        raise TypeError,'cannot convert arguments to DateTime'
+        raise TypeError(
+            'cannot convert date arguments to DateTime: args=%r, kws=%r' %
+            (args, kws))
 
 def DateTimeDeltaFrom(*args, **kws):
 
@@ -282,19 +366,36 @@ def DateTimeDeltaFrom(*args, **kws):
         Generic DateTimeDelta instance constructor. Can handle parsing
         strings, numbers and keywords.
 
-        XXX Add support for Unicode.
-
     """
     if len(args) == 1:
         # Single argument
         arg = args[0]
         if _isstring(arg):
             import Parser
-            return apply(Parser.DateTimeDeltaFromString, args, kws)
+            return Parser.DateTimeDeltaFromString(*args, **kws)
         elif type(arg) is DateTimeDeltaType:
             return arg
         elif type(arg) is DateTimeType:
             raise TypeError,'cannot convert DateTime to DateTimeDelta'
+        elif isinstance(arg, _pytime):
+            if arg.tzinfo is not None:
+                # Convert to UTC
+                offset = arg.utcoffset()
+                # Another datetime module quirk: time - timedelta
+                # doesn't work, so we have to use a different method
+                # of adjusting the result
+                return DateTimeDelta(0,
+                                     arg.hour, arg.minute,
+                                     arg.second + arg.microsecond * 1e-6
+                                     - offset.seconds)
+            else:
+                return DateTimeDelta(0,
+                                     arg.hour, arg.minute,
+                                     arg.second + arg.microsecond * 1e-6)
+        elif isinstance(arg, _pytimedelta):
+            return DateTimeDelta(arg.days,
+                                 0, 0,
+                                 arg.seconds + arg.microseconds * 1e-6)
         else:
             try:
                 value = float(arg)
@@ -305,7 +406,7 @@ def DateTimeDeltaFrom(*args, **kws):
 
     elif len(args) > 1:
         # Assume the arguments are the same as for DateTimeDelta()
-        return apply(DateTimeDelta, args, kws)
+        return DateTimeDelta(*args, **kws)
 
     elif len(kws) > 0:
         # Keyword arguments; default: 00:00:00:00.00
@@ -325,17 +426,15 @@ def TimeDeltaFrom(*args, **kws):
         Generic TimeDelta instance constructor. Can handle parsing
         strings, numbers and keywords.
 
-        XXX Add support for Unicode.
-
     """
     if len(args) > 1:
         # Assume the arguments are the same as for TimeDelta(): without
         # days part !
-        return apply(DateTimeDelta, (0,)+args, kws)
+        return DateTimeDelta(0, *args, **kws)
     else:
         # Otherwise treat the arguments just like for DateTimeDelta
         # instances.
-        return apply(DateTimeDeltaFrom, args, kws)
+        return DateTimeDeltaFrom(*args, **kws)
 
 def DateFromTicks(ticks,
                   # Locals:
@@ -348,7 +447,7 @@ def DateFromTicks(ticks,
         The time part is ignored.
 
     """
-    return apply(DateTime, localtime(ticks)[:3])
+    return DateTime(*localtime(ticks)[:3])
 
 def TimestampFromTicks(ticks,
                        # Locals:
@@ -360,7 +459,7 @@ def TimestampFromTicks(ticks,
         time indicated by the given ticks value.
 
     """
-    return apply(DateTime, localtime(ticks)[:6])
+    return DateTime(*localtime(ticks)[:6])
 
 def TimeFromTicks(ticks,
                   # Locals:
@@ -372,7 +471,7 @@ def TimeFromTicks(ticks,
         indicated by the given ticks value. The date part is ignored.
 
     """
-    return apply(DateTimeDelta, (0,) + localtime(ticks)[3:6])
+    return DateTimeDelta(0, *localtime(ticks)[3:6])
 
 # Aliases
 utctime = gmtime
@@ -382,7 +481,6 @@ DateTimeFromTicks = localtime
 Date = DateTime
 Time = TimeDelta
 Timestamp = DateTime
-DateFrom = DateTimeFrom # XXX should only parse the date part !
 TimeFrom = TimeDeltaFrom
 TimestampFrom = DateTimeFrom
 GregorianDateTime = DateTime
@@ -462,9 +560,9 @@ Month = {2: 'February', 3: 'March', None: 0, 'July': 7, 11: 'November',
     'January', 0: None}
 
 # Limits (see also the range checks in mxDateTime.c)
-MaxDateTime = DateTime(5867440,12,31) 
-MinDateTime = DateTime(-5851455,1,1)
-MaxDateTimeDelta = DateTimeDeltaFromSeconds(2147483647 * 86400.0)
+MaxDateTime = DateTime(_sys.maxint / 366 - 1, 12, 31) 
+MinDateTime = DateTime(-_sys.maxint / 366 + 2, 1, 1)
+MaxDateTimeDelta = DateTimeDeltaFromSeconds(_sys.maxint * 86400.0)
 MinDateTimeDelta = -MaxDateTimeDelta
 
 ###
@@ -799,9 +897,7 @@ class RelativeDateTime:
         self._hash = x
         return x
 
-    def __str__(self,
-
-                join=_string.join):
+    def __str__(self):
 
         l = []
         append = l.append
@@ -874,7 +970,7 @@ class RelativeDateTime:
         else:
             append('SS')
             
-        return join(l,'')
+        return ''.join(l)
 
     def __repr__(self):
 
@@ -899,7 +995,7 @@ def RelativeDateTimeFrom(*args, **kws):
         arg = args[0]
         if _isstring(arg):
             import Parser
-            return apply(Parser.RelativeDateTimeFromString, args, kws)
+            return Parser.RelativeDateTimeFromString(*args, **kws)
         elif isinstance(arg, RelativeDateTime):
             return arg
         else:
@@ -907,7 +1003,7 @@ def RelativeDateTimeFrom(*args, **kws):
                   'cannot convert argument to RelativeDateTime'
 
     else:
-        return apply(RelativeDateTime,args,kws)
+        return RelativeDateTime(*args, **kws)
 
 def RelativeDateTimeDiff(date1,date2,
 
