@@ -2,7 +2,7 @@
   mxProxy -- Proxy wrapper type
 
   Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -23,11 +23,18 @@
 /* Mark the module as Py_ssize_t clean. */
 #define PY_SSIZE_T_CLEAN 1
 
+/* Setup mxstdlib memory management */
+#if 1
+# define MAL_USE_PYMALLOC
+#else
+# define MAL_USE_C_MALLOC
+#endif
+
 #include "mx.h"
 #include "mxProxy.h"
 
 /* Version number: Major.Minor.Patchlevel */
-#define MXPROXY_VERSION "3.1.2"
+#define MXPROXY_VERSION "3.2.0"
 
 /* Define these to have the module use free lists (saves malloc calls) */
 #define MXPROXY_FREELIST
@@ -39,7 +46,7 @@ static char *Module_docstring =
  MXPROXY_MODULE" -- Generic proxy wrapper type. Version "MXPROXY_VERSION"\n\n"
 
  "Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
