@@ -2,7 +2,7 @@
   mxQueue -- A queue implementation
 
   Copyright (c) 1999-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -23,10 +23,17 @@
 /* Mark the module as Py_ssize_t clean. */
 #define PY_SSIZE_T_CLEAN 1
 
+/* Setup mxstdlib memory management */
+#if 1
+# define MAL_USE_PYMALLOC
+#else
+# define MAL_USE_C_MALLOC
+#endif
+
 #include "mx.h"
 #include "mxQueue.h"
 
-#define MXQUEUE_VERSION "3.1.2"
+#define MXQUEUE_VERSION "3.2.0"
 
 /* The minimal size of queues; must be > 1 */
 #define MINIMAL_QUEUESIZE	4
@@ -47,7 +54,7 @@ static char *Module_docstring =
  MXQUEUE_MODULE" -- A queue implementation. Version "MXQUEUE_VERSION"\n\n"
 
  "Copyright (c) 1999-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -763,7 +770,12 @@ int mxQueue_Compare(PyObject *left,
 	if (cmp != 0)
 	    return cmp;
     }
-    return v_len - w_len;
+    if (v_len < w_len)
+	return -1;
+    else if (v_len == w_len)
+	return 0;
+    else
+	return 1;
 }
 
 static
