@@ -2,7 +2,7 @@
   mxStack -- A stack implementation
 
   Copyright (c) 1997-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -23,10 +23,17 @@
 /* Mark the module as Py_ssize_t clean. */
 #define PY_SSIZE_T_CLEAN 1
 
+/* Setup mxstdlib memory management */
+#if 1
+# define MAL_USE_PYMALLOC
+#else
+# define MAL_USE_C_MALLOC
+#endif
+
 #include "mx.h"
 #include "mxStack.h"
 
-#define MXSTACK_VERSION "3.1.2"
+#define MXSTACK_VERSION "3.2.0"
 
 /* The minimal size of stacks; must be > 1 */
 #define MINIMAL_STACKSIZE	4
@@ -47,7 +54,7 @@ static char *Module_docstring =
  MXSTACK_MODULE" -- A stack implementation. Version "MXSTACK_VERSION"\n\n"
 
  "Copyright (c) 1997-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -199,7 +206,7 @@ static
 void mxStack_Free(register mxStackObject *stack)
 {
     if (stack->array) {
-	int i;
+	Py_ssize_t i;
 	
 	for (i = 0; i <= stack->top; i++)
 	    Py_DECREF(stack->array[i]);
@@ -216,7 +223,7 @@ static
 int mxStack_Push(register mxStackObject *stack,
 		 PyObject *v)
 {
-    int top;
+    Py_ssize_t top;
     
     if (stack == NULL) {
 	PyErr_BadInternalCall();
@@ -228,7 +235,7 @@ int mxStack_Push(register mxStackObject *stack,
     /* Grow the stack, if we hit the array boundary */
     if (top == stack->size) {
 	register PyObject **w;
-	register int size;
+	register Py_ssize_t size;
 
 	size = stack->size;
 	GROW(size);
@@ -253,9 +260,9 @@ static
 int mxStack_PushMany(register mxStackObject *stack,
 		     PyObject *seq)
 {
-    int top;
-    register int i;
-    int length;
+    Py_ssize_t top;
+    register Py_ssize_t i;
+    Py_ssize_t length;
 
     if (stack == NULL) {
 	PyErr_BadInternalCall();
@@ -271,7 +278,7 @@ int mxStack_PushMany(register mxStackObject *stack,
     /* Grow the stack, if we hit the array boundary */
     if (top + length >= stack->size) {
 	register PyObject **w;
-	register int size;
+	register Py_ssize_t size;
 
 	size = stack->size;
 	while (top + length >= size)
@@ -716,7 +723,12 @@ int mxStack_Compare(PyObject *left,
 	if (cmp != 0)
 	    return cmp;
 	}
-    return v->top - w->top;
+    if (v->top < w->top)
+	return -1;
+    else if (v->top == w->top)
+	return 0;
+    else
+	return 1;
 }
 
 static
