@@ -3,12 +3,12 @@
 """ Loop - loop examples (Version 0.1)
     
     Copyright (c) 2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-    Copyright (c) 2000-2008, eGenix.com Software GmbH; mailto:info@egenix.com
+    Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
     See the documentation for further information on copyrights,
     or contact the author. All Rights Reserved.
 """
 
-import sys,string
+import sys
 
 # engine + constants
 from mx.TextTools import *
