@@ -2,7 +2,7 @@
   mxTools -- Misc. utilities for Python
 
   Copyright (c) 1997-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -24,6 +24,13 @@
 /* Mark the module as Py_ssize_t clean. */
 #define PY_SSIZE_T_CLEAN 1
 
+/* Setup mxstdlib memory management */
+#if 1
+# define MAL_USE_PYMALLOC
+#else
+# define MAL_USE_C_MALLOC
+#endif
+
 #include "mx.h"
 #include "mxTools.h"
 
@@ -45,7 +52,7 @@
 # include <dlfcn.h>
 #endif
 
-#define MXTOOLS_VERSION "3.1.2"
+#define MXTOOLS_VERSION "3.2.0"
 
 /* To open up the playground for new ideas... */
 /*#define INCLUDE_FUNSTUFF*/
@@ -60,7 +67,7 @@ static char *Module_docstring =
  MXTOOLS_MODULE" -- A tool collection. Version "MXTOOLS_VERSION"\n\n"
 
  "Copyright (c) 1997-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -2231,7 +2238,15 @@ Py_C_Function( mxTools_dlopen,
 	       )
 {
     char *libname;
+#if HAVE_INTERPRETER_DLOPENFLAGS
     int mode = PyThreadState_GET()->interp->dlopenflags;
+#else
+# ifdef RTLD_NOW
+    int mode = RTLD_NOW;
+# else
+    intt mode = RTLD_LAZY;
+# endif
+#endif
     void *handle = 0;
     
     Py_Get2Args("s|i", libname, mode);
@@ -2255,11 +2270,11 @@ Py_C_Function( mxTools_dlopen,
 /* Helper for mxTools_verscmp */
 
 static
-int parselevel(char *s,
-	       Py_ssize_t len,
-	       Py_ssize_t start,
-	       int *number,
-	       char *rest)
+Py_ssize_t parselevel(char *s,
+		      Py_ssize_t len,
+		      Py_ssize_t start,
+		      int *number,
+		      char *rest)
 {
     Py_ssize_t i;
     Py_ssize_t split = -1, number_len;
