@@ -2,7 +2,7 @@
   mxUID -- An UID datatype
 
   Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -24,13 +24,20 @@
 /* Mark the module as Py_ssize_t clean. */
 #define PY_SSIZE_T_CLEAN 1
 
+/* Setup mxstdlib memory management */
+#if 1
+# define MAL_USE_PYMALLOC
+#else
+# define MAL_USE_C_MALLOC
+#endif
+
 #include "mx.h"
 #include "mxUID.h"
 #include <ctype.h>
 #include <time.h>
 
 /* Version number: Major.Minor.Patchlevel */
-#define MXUID_VERSION "3.1.2"
+#define MXUID_VERSION "3.2.0"
 
 /* Additional includes needed for mxUID_GetCurrentTime() API */
 # if defined(HAVE_SYS_TIME_H) && defined(TIME_WITH_SYS_TIME)
@@ -61,7 +68,7 @@ static char *Module_docstring =
  "Version "MXUID_VERSION"\n\n"
 
  "Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -176,10 +183,11 @@ PyObject *notimplemented3(PyObject *u, PyObject *v, PyObject *w)
 /* --- internal functions --- */
 
 static
-unsigned int mxUID_CRC32(unsigned char *s,
+unsigned int mxUID_CRC32(char *str,
 			 Py_ssize_t len)
 {
     Py_ssize_t i,j;
+    register unsigned char *s = (unsigned char *)str;
     register int x;
     register int y;
 
@@ -196,10 +204,11 @@ unsigned int mxUID_CRC32(unsigned char *s,
 }
     
 static
-unsigned short mxUID_CRC16(unsigned char *s,
+unsigned short mxUID_CRC16(char *str,
 			   Py_ssize_t len)
 {
     Py_ssize_t i,j;
+    register unsigned char *s = (unsigned char *)str;
     register int x;
     register int y;
 
@@ -225,25 +234,27 @@ unsigned short mxUID_CRC16(unsigned char *s,
 */
 
 static
-void mxUID_Fold(unsigned char *in,
+void mxUID_Fold(char *in_str,
 		Py_ssize_t in_len,
-		unsigned char *out,
+		char *out_str,
 		Py_ssize_t out_len)
 {
     Py_ssize_t chunksize;
+    register unsigned char *in = (unsigned char *)in_str;
+    register unsigned char *out = (unsigned char *)out_str;
     
     /* First pass */
-    chunksize = min(in_len,out_len);
-    memcpy(out,in,chunksize);
+    chunksize = min(in_len, out_len);
+    memcpy(out, in, chunksize);
     if (chunksize < out_len)
-	memset(out+chunksize,out_len-chunksize,'\0');
+	memset(out + chunksize, 0, out_len - chunksize);
     in += chunksize;
     in_len -= chunksize;
 
     /* Next passes */
     while (in_len > 0) {
 	register Py_ssize_t i;
-	chunksize = min(in_len,out_len);
+	chunksize = min(in_len, out_len);
 	for (i = 0; i < chunksize; i++)
 	    out[i] ^= in[i];
 	in += chunksize;
@@ -320,7 +331,7 @@ int mxUID_OneTimePad(unsigned char *data,
    string, this must be given too. Otherwise, NULL may be used. */
 
 static
-int mxUID_Verify(unsigned char *uid,
+int mxUID_Verify(char *uid,
 		 Py_ssize_t uid_len,
 		 char *code)
 {
@@ -330,7 +341,7 @@ int mxUID_Verify(unsigned char *uid,
     if (uid_len < 32)
 	return 0;
     crc16 = (int)mxUID_CRC16(uid, uid_len - 4);
-    if (sscanf(uid + uid_len - 4, "%x", &value) <= 0)
+    if (sscanf((char *)(uid + uid_len - 4), "%x", &value) <= 0)
 	return 0;
     DPRINTF("crc=%i, value=%i\n", crc16, value);
     if (crc16 != value)
@@ -592,7 +603,7 @@ Py_C_Function( mxUID_verify,
 	       "given in case it was used to create the UID."
 	       )
 {
-    unsigned char *s;
+    char *s;
     Py_ssize_t len;
     char *code = NULL;
     
@@ -615,7 +626,7 @@ Py_C_Function( mxUID_fold,
 	       "from string by XOR folding it."
 	       )
 {
-    unsigned char *s;
+    char *s;
     Py_ssize_t size = 8;
     Py_ssize_t len;
     PyObject *v = NULL;
@@ -627,7 +638,7 @@ Py_C_Function( mxUID_fold,
     if (!v)
 	goto onError;
     
-    mxUID_Fold(s,len,(unsigned char *)PyString_AS_STRING(v),size);
+    mxUID_Fold(s, len, PyString_AS_STRING(v), size);
     return v;
 
  onError:
@@ -672,7 +683,7 @@ Py_C_Function( mxUID_crc,
     int bits = 32;
     Py_ssize_t len;
     long crc;
-    unsigned char *s;
+    char *s;
     
     Py_Get3Args("s#|i",
 		s, len, bits);
