@@ -2,7 +2,7 @@
   mxURL -- An URL datatype
 
   Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -24,12 +24,19 @@
 /* Mark the module as Py_ssize_t clean. */
 #define PY_SSIZE_T_CLEAN 1
 
+/* Setup mxstdlib memory management */
+#if 1
+# define MAL_USE_PYMALLOC
+#else
+# define MAL_USE_C_MALLOC
+#endif
+
 #include "mx.h"
 #include "mxURL.h"
 #include <ctype.h>
 
 /* Version number: Major.Minor.Patchlevel */
-#define MXURL_VERSION "3.1.2"
+#define MXURL_VERSION "3.2.0"
 
 /* Define this to have the module use a free list for URLs */
 #define MXURL_FREELIST
@@ -49,7 +56,7 @@ static char *Module_docstring =
  "Version "MXURL_VERSION"\n\n"
 
  "Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2009, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -383,8 +390,8 @@ int mxURL_SetSchemeAndFeatures(mxURLObject *url,
    0-terminated. */
 
 static
-int mxURL_NormalizePath(register char *path,
-			Py_ssize_t path_len)
+Py_ssize_t mxURL_NormalizePath(register char *path,
+			       Py_ssize_t path_len)
 {
     register Py_ssize_t i;
     register Py_ssize_t j;
@@ -671,7 +678,8 @@ int mxURL_SetFromString(mxURLObject *url,
     /* Character set of all allowed scheme characters; generated from
        TextTools.set(alpha + number + '+-.'). */
     static unsigned char *scheme_set = 
-	("\000\000\000\000\000h\377\003\376\377"
+	(unsigned char *)(
+	 "\000\000\000\000\000h\377\003\376\377"
 	 "\377\007\376\377\377\007\000\000\000\000"
 	 "\000\000\000\000\000\000\000\000\000\000\000\000");
 
@@ -980,7 +988,7 @@ PyObject *mxURL_PathEntry(mxURLObject *self,
 /* Returns the path length using the semantics of mxURL_PathEntry().  */
 
 static
-int mxURL_PathLength(mxURLObject *self)
+Py_ssize_t mxURL_PathLength(mxURLObject *self)
 {
     register Py_ssize_t i;
     Py_ssize_t len = self->path_len;
@@ -2084,7 +2092,7 @@ Py_C_Function( mxURL_depth,
     depth = mxURL_Depth(url);
     if (depth < 0)
 	goto onError;
-    return PyInt_FromLong(depth);
+    return PyInt_FromSsize_t(depth);
  onError:
     return NULL;
 }
@@ -2181,7 +2189,7 @@ Py_C_Function( mxURL_pathlen,
     length = mxURL_PathLength(url);
     if (length < 0)
 	goto onError;
-    return PyInt_FromLong(length);
+    return PyInt_FromSsize_t(length);
  onError:
     return NULL;
 }
